@@ -12,6 +12,20 @@ lal;
 assert(exist("lal"));
 disp("PASSED module load");
 
+# set error handlers
+function set_nice_error_handlers()
+  swig_set_nice_error_handlers();
+endfunction
+function set_default_error_handlers()
+  lal;
+  if length(getenv("NASTY_ERROR_HANDLERS")) > 0
+    swig_set_nasty_error_handlers();
+  else
+    swig_set_nice_error_handlers();
+  endif
+endfunction
+set_default_error_handlers();
+
 ## check object parent tracking
 disp("checking object parent tracking ...");
 a = lalburst.new_swig_lalburst_test_parent_map_struct();
